@@ -207,7 +207,7 @@ if sys.version < '2.2.3':
     DistributionMetadata.download_url = None
 
 classifiers = [
-    'Development Status :: 4 - Beta',
+    'Development Status :: 5 - Production/Stable',
     'Environment :: Console',
     'Intended Audience :: Developers',
     'Intended Audience :: End Users/Desktop',
@@ -219,7 +219,7 @@ classifiers = [
 ]
 
 setup(name             = "QuantLib-Python",
-      version          = "0.9.9",
+      version          = "1.0",
       description      = "Python bindings for the QuantLib library",
       long_description = """
 QuantLib (http://quantlib.org/) is a C++ library for financial quantitative
